# pydgin

A galactic dynamics interface (a [pidgin](https://en.wikipedia.org/wiki/Pidgin), if you will) using existing galactic dynamics libraries in Python (`galpy`, `gala` and `agama`) as backends.
